<div align="center">
<img src="docs/figures/pysyd_logo_inv.png" width="60%">

## **Automated Measurements of Global Asteroseismic Parameters**

[![PyPI](https://badge.fury.io/py/pysyd.svg)](https://badge.fury.io/py/pysyd)
[![Documentation](https://readthedocs.org/projects/pysyd/badge/?version=latest)](https://pysyd.readthedocs.io/en/latest/?badge=latest)
[![License: MIT](https://img.shields.io/badge/License-MIT-orange.svg)](https://opensource.org/licenses/MIT)
[![JOSS](https://joss.theoj.org/papers/6465a9dd3141c207175f200c7f891f1e/status.svg)](https://joss.theoj.org/papers/6465a9dd3141c207175f200c7f891f1e)

</div>

--------------------------------------------------------------------------------

## Attribution

Written & developed by Ashley Chontos, Daniel Huber, Maryum Sayeed and Pavadol Yamsiri.

We thank Dennis Stello, Jie Yu, Marc Hon, and other users of the IDL `SYD` pipeline for discussion and suggestions which helped the development of this code.

Please cite our [JOSS paper](https://joss.theoj.org/papers/6465a9dd3141c207175f200c7f891f1e) as well as the [original publication](https://ui.adsabs.harvard.edu/abs/2009CoAst.160...74H/abstract) discussing the methodology if you make use of `pySYD` in your work.

## Documentation

Read the documentation at [pysyd.readthedocs.io](https://pysyd.readthedocs.io)
